@@ -1,9 +1,5 @@
 package Catalyst::Plugin::ErrorCatcher;
-$Catalyst::Plugin::ErrorCatcher::VERSION = '0.0.8.20';
-{
-  $Catalyst::Plugin::ErrorCatcher::DIST = 'Catalyst-Plugin-ErrorCatcher';
-}
-
+$Catalyst::Plugin::ErrorCatcher::VERSION = '0.0.8.21';
 # ABSTRACT: Catch application errors and emit them somewhere
 use Moose;
     with 'Catalyst::ClassData';
@@ -577,7 +573,7 @@ Catalyst::Plugin::ErrorCatcher - Catch application errors and emit them somewher
 
 =head1 VERSION
 
-version 0.0.8.20
+version 0.0.8.21
 
 =head1 SYNOPSIS
 
