@@ -1,9 +1,5 @@
 package Catalyst::Plugin::ErrorCatcher::File;
-$Catalyst::Plugin::ErrorCatcher::File::VERSION = '0.0.8.20';
-{
-  $Catalyst::Plugin::ErrorCatcher::File::DIST = 'Catalyst-Plugin-ErrorCatcher';
-}
-
+$Catalyst::Plugin::ErrorCatcher::File::VERSION = '0.0.8.21';
 # ABSTRACT: a file emitter for Catalyst::Plugin::ErrorCatcher
 use strict;
 use warnings;
@@ -87,7 +83,7 @@ Catalyst::Plugin::ErrorCatcher::File - a file emitter for Catalyst::Plugin::Erro
 
 =head1 VERSION
 
-version 0.0.8.20
+version 0.0.8.21
 
 =head1 SYNOPSIS
 
