@@ -1,9 +1,5 @@
 package Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::CaughtException;
-$Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::CaughtException::VERSION = '0.0.8.20';
-{
-  $Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::CaughtException::DIST = 'Catalyst-Plugin-ErrorCatcher';
-}
-
+$Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::CaughtException::VERSION = '0.0.8.21';
 use strict;
 use warnings;
 
@@ -44,7 +40,7 @@ Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::CaughtException - cleanup caugh
 
 =head1 VERSION
 
-version 0.0.8.20
+version 0.0.8.21
 
 =head2 tidy_message($self, $stringref)
 
