@@ -1,9 +1,5 @@
 package Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::Pg::MissingColumn;
-$Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::Pg::MissingColumn::VERSION = '0.0.8.20';
-{
-  $Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::Pg::MissingColumn::DIST = 'Catalyst-Plugin-ErrorCatcher';
-}
-
+$Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::Pg::MissingColumn::VERSION = '0.0.8.21';
 use strict;
 use warnings;
 
@@ -42,7 +38,7 @@ Catalyst::Plugin::ErrorCatcher::Plugin::CleanUp::Pg::MissingColumn - cleanup col
 
 =head1 VERSION
 
-version 0.0.8.20
+version 0.0.8.21
 
 =head2 tidy_message($self, $stringref)
 
